@@ -11,6 +11,7 @@ from datetime import datetime
 from io import BytesIO
 from pprint import pformat
 from subprocess import CalledProcessError
+from unittest.mock import Mock
 from urllib.parse import urlparse
 from urllib.request import urlopen
 
@@ -37,6 +38,7 @@ base_schema = Schema(
         Required("build_date"): int,
         Required("build_number"): int,
         Required("do_not_optimize"): [str],
+        Required("enable_always_target"): Any(bool, [str]),
         Required("existing_tasks"): {str: str},
         Required("filters"): [str],
         Required("head_ref"): str,
@@ -53,7 +55,7 @@ base_schema = Schema(
         Required("pushdate"): int,
         Required("pushlog_id"): str,
         Required("repository_type"): str,
-        # target-kind is not included, since it should never be
+        # target-kinds is not included, since it should never be
         # used at run-time
         Required("target_tasks_method"): str,
         Required("tasks_for"): str,
@@ -78,12 +80,22 @@ def get_version(repo_path):
 
 def _get_defaults(repo_root=None):
     repo_path = repo_root or os.getcwd()
-    repo = get_repository(repo_path)
+    try:
+        repo = get_repository(repo_path)
+    except RuntimeError:
+        # Use fake values if no repo is detected.
+        repo = Mock(branch="", head_rev="", tool="git")
+        repo.get_url.return_value = ""
+
     try:
         repo_url = repo.get_url()
         parsed_url = mozilla_repo_urls.parse(repo_url)
         project = parsed_url.repo_name
-    except (CalledProcessError, mozilla_repo_urls.errors.InvalidRepoUrlError):
+    except (
+        CalledProcessError,
+        mozilla_repo_urls.errors.InvalidRepoUrlError,
+        mozilla_repo_urls.errors.UnsupportedPlatformError,
+    ):
         repo_url = ""
         project = ""
 
@@ -94,6 +106,7 @@ def _get_defaults(repo_root=None):
         "build_date": int(time.time()),
         "build_number": 1,
         "do_not_optimize": [],
+        "enable_always_target": True,
         "existing_tasks": {},
         "filters": ["target_tasks_method"],
         "head_ref": repo.branch or repo.head_rev,
@@ -271,7 +284,7 @@ class Parameters(ReadOnlyDict):
             else:
                 raise ParameterMismatch(
                     "Don't know how to determine file URL for non-github"
-                    "repo: {}".format(repo)
+                    f"repo: {repo}"
                 )
         else:
             raise RuntimeError(
