@@ -111,6 +111,42 @@ def test_always_target_tasks(maketgg):
         ["_fake-t-0", "_fake-t-1", "_ignore-t-0", "_ignore-t-1"]
     )
 
+    # Test `enable_always_target: ["_fake"]`
+    tgg_args = {
+        "target_tasks": ["_fake-t-0", "_fake-t-1", "_ignore-t-0", "_ignore-t-1"],
+        "kinds": [
+            (
+                "_fake",
+                {
+                    "task-defaults": {
+                        "attributes": {"always_target": True},
+                        "optimization": {"odd": None},
+                    }
+                },
+            ),
+            (
+                "_ignore",
+                {
+                    "task-defaults": {
+                        "attributes": {"always_target": True},
+                        "optimization": {"even": None},
+                    }
+                },
+            ),
+        ],
+        "params": {"enable_always_target": ["_fake"], "optimize_target_tasks": False},
+    }
+    tgg = maketgg(**tgg_args)
+    assert sorted(tgg.target_task_set.tasks.keys()) == sorted(
+        ["_fake-t-0", "_fake-t-1", "_ignore-t-0", "_ignore-t-1"]
+    )
+    assert sorted(tgg.target_task_graph.tasks.keys()) == sorted(
+        ["_fake-t-0", "_fake-t-1", "_fake-t-2", "_ignore-t-0", "_ignore-t-1"]
+    )
+    assert sorted(t.label for t in tgg.optimized_task_graph.tasks.values()) == sorted(
+        ["_fake-t-0", "_fake-t-1", "_fake-t-2", "_ignore-t-0", "_ignore-t-1"]
+    )
+
 
 def test_optimized_task_graph(maketgg):
     "The optimized task graph contains task ids"
@@ -146,7 +182,7 @@ def test_load_tasks_for_kind(monkeypatch):
         pytest.param(
             {},
             [
-                "taskgraph.transforms.job:transforms",
+                "taskgraph.transforms.run:transforms",
                 "taskgraph.transforms.task:transforms",
             ],
             id="no_transforms",
@@ -155,7 +191,7 @@ def test_load_tasks_for_kind(monkeypatch):
             {"transforms": ["taskgraph.transforms.notify:transforms"]},
             [
                 "taskgraph.transforms.notify:transforms",
-                "taskgraph.transforms.job:transforms",
+                "taskgraph.transforms.run:transforms",
                 "taskgraph.transforms.task:transforms",
             ],
             id="additional_transform_specified",
@@ -178,15 +214,15 @@ def test_default_loader(config, expected_transforms):
         pytest.param(
             {
                 "transforms": [
-                    "taskgraph.transforms.job:transforms",
+                    "taskgraph.transforms.run:transforms",
                     "taskgraph.transforms.task:transforms",
                 ]
             },
-            id="job_and_task_transforms_specified",
+            id="run_and_task_transforms_specified",
         ),
         pytest.param(
-            {"transforms": ["taskgraph.transforms.job:transforms"]},
-            id="only_job_transform_specified",
+            {"transforms": ["taskgraph.transforms.run:transforms"]},
+            id="only_run_transform_specified",
         ),
         pytest.param(
             {"transforms": ["taskgraph.transforms.task:transforms"]},
