@@ -421,7 +421,17 @@ def test_find_latest_common_revision(repo_with_remote):
             repo.find_latest_common_revision(base_ref, repo.head_rev)
             == expected_latest_common_revision
         )
-    else:
+
+        # Test no common ancestors
+        repo.run("checkout", "--orphan", "new_branch")
+        repo.run("add", ".")
+        repo.run("commit", "-m", "Add another new revision")
+        base_ref = f"{remote_name}/{repo.branch}"
+        assert (
+            repo.find_latest_common_revision(base_ref, repo.head_rev)
+            == Repository.NULL_REVISION
+        )
+    elif repo.tool == "hg":
         # hg doesn't have the concept of remote branches
         assert (
             repo.find_latest_common_revision(
@@ -430,6 +440,20 @@ def test_find_latest_common_revision(repo_with_remote):
             == expected_latest_common_revision
         )
 
+        # Test no common ancestors
+        repo.run("update", Repository.NULL_REVISION)
+        with open(os.path.join(repo.path, "some_file"), "w") as f:
+            f.write("some content")
+
+        repo.run("add", ".")
+        repo.run("commit", "-m", "Add another new revision")
+        assert (
+            repo.find_latest_common_revision(
+                repo.head_rev, expected_latest_common_revision
+            )
+            == Repository.NULL_REVISION
+        )
+
 
 def test_does_revision_exist_locally(repo):
     first_revision = repo.head_rev
